.. _vmware_rest_scenarios:

****************************
VMware REST Scenarios
****************************

These scenarios teach you how to accomplish common VMware tasks using the REST API and the Ansible ``vmware.vmware_rest`` collection. To get started, please select the task you want to accomplish.

.. toctree::
   :maxdepth: 1

   vmware_rest_scenarios/installation
   vmware_rest_scenarios/authentication
   vmware_rest_scenarios/collect_information
   vmware_rest_scenarios/create_vm
   vmware_rest_scenarios/vm_info
   vmware_rest_scenarios/vm_hardware_tuning
   vmware_rest_scenarios/run_a_vm
   vmware_rest_scenarios/vm_tool_information
   vmware_rest_scenarios/vm_tool_configuration
